Function that appends informative alteration names to sample variants based on gene symbol, consequence and HGVS annotations
Source:R/variant_annotation.R
append_alteration_name.RdFunction that appends informative alteration names to sample variants based on gene symbol, consequence and HGVS annotations