Function that assigns a maximum value to a variable (gnomAD_NC_FAF_GRPMAX) reflecting the filter allele frequency (GrpMAX) for a given variant in the non-cancer gnomAD subset (v3.1)
Source:R/germline.R
grpmax_faf_nc_gnomad.RdFunction that assigns a maximum value to a variable (gnomAD_NC_FAF_GRPMAX) reflecting the filter allele frequency (GrpMAX) for a given variant in the non-cancer gnomAD subset (v3.1)