Function that initiates report element with biomarker evidence information
Source:R/report.R
init_biomarker_content.RdFunction that initiates report element with biomarker evidence information

R/report.R
init_biomarker_content.RdFunction that initiates report element with biomarker evidence information