Skip to contents

Function that loads YAML data with settings and file paths to annotated molecular profiles

Usage

load_yaml(
  yaml_fname,
  report_mode = "CPSR",
  color_palette = pcgrr::color_palette
)

Arguments

yaml_fname

Yaml file with configuration settings and paths to annotated molecular datasets

report_mode

Type of report ('PCGR' or 'CPSR')