Character vector with OncoKB annotations coming from the MafAnnotator / FusionAnnotator / CnaAnnnotator tools in the PCGR Python workflow. These annotations are used for variant classification and reporting in PCGR.
Source:R/data.R
oncokb_annotations.RdCharacter vector with OncoKB annotations coming from the MafAnnotator / FusionAnnotator / CnaAnnnotator tools in the PCGR Python workflow. These annotations are used for variant classification and reporting in PCGR.