Function that plots four value boxes with the most important findings in the cancer genome
Source:R/value_boxes.R
plot_value_boxes.RdFunction that plots four value boxes with the most important findings in the cancer genome
Usage
plot_value_boxes(pcg_report, color_palette = pcgrr::color_palette)