Skip to contents

Function that assigns a maximum value to a variable (gnomAD_AF_POPMAX) reflecting the maximum allele frequency for a given variant across gnomAD populations

Usage

popmax_af_gnomad(sample_calls)

Arguments

sample_calls

data frame with sample variant calls