Skip to contents

Render a value between 0 and 1 as a horizontal bar (Generated by Claude Opus 4.6 with some manual tweaks)

Usage

render_bar_cell(
  fill_color = "#5D5165",
  bg_color = "#e8e8e8",
  show_value = TRUE
)

Arguments

fill_color

Color of the bar

bg_color

Background track color

show_value

Whether to show the numeric value alongside

Value

A function that can be used as a reactable cell renderer for numeric columns, which renders the value as a horizontal bar