Render diagnosis cell with background color based on actionability tier (Generated by Claude Opus 4.6 with some manual tweaks)
Source:R/render_table.R
render_diagnosis.RdRender diagnosis cell with background color based on actionability tier (Generated by Claude Opus 4.6 with some manual tweaks)