Render prognostic outcome cell with background color based on actionability tier (Generated by Claude Opus 4.6 with some manual tweaks)
Source:R/render_table.R
render_prognostic_outcome.RdRender prognostic outcome cell with background color based on actionability tier (Generated by Claude Opus 4.6 with some manual tweaks)