Render therapy match cell with background color based on actionability tier (Generated by Claude Opus 4.6 with some manual tweaks)
Source:R/render_table.R
render_therapy_style.RdRender therapy match cell with background color based on actionability tier (Generated by Claude Opus 4.6 with some manual tweaks)