Skip to contents

Function that generate stats for a germline variant callset, including number of variants and number of variants with evidence items for each BM evidence type

Usage

stats_report_germline(var_df = NULL, vartype = "snv_indel")

Arguments

var_df

data.frame with germline variant data (SNVs/InDels)

vartype

type of variant ('snv_indel')