Function that loads YAML data with settings and file paths to annotated molecular profiles
Source:R/report.R
load_yaml.RdFunction that loads YAML data with settings and file paths to annotated molecular profiles
Usage
load_yaml(
yaml_fname,
report_mode = "CPSR",
color_palette = pcgrr::color_palette
)