Function that plots the indel fraction for a given sample and contrasts this with the distribution for MSI-H/MSS samples from TCGA
Source:R/msi.R
msi_indel_fraction_plot.RdFunction that plots the indel fraction for a given sample and contrasts this with the distribution for MSI-H/MSS samples from TCGA
Usage
msi_indel_fraction_plot(
tcga_msi_dataset,
indel_fraction,
color_palette = pcgrr::color_palette
)