Function that plots the indel load for a given sample and contrasts this with the distribution for MSI-H/MSS samples from TCGA
Source:R/msi.R
msi_indel_load_plot.RdFunction that plots the indel load for a given sample and contrasts this with the distribution for MSI-H/MSS samples from TCGA
Usage
msi_indel_load_plot(
tcga_msi_dataset,
indel_load,
color_palette = pcgrr::color_palette
)