Function that assigns a maximum value to a variable (gnomAD_AF_POPMAX) reflecting the maximum allele frequency for a given variant across gnomAD populations
Source:R/germline.R
popmax_af_gnomad.RdFunction that assigns a maximum value to a variable (gnomAD_AF_POPMAX) reflecting the maximum allele frequency for a given variant across gnomAD populations