Style alteration cell background based on cancer association rank (Generated by Claude Opus 4.6 with some manual tweaks)
Source:R/render_table.R
render_symbol_assoc_style.RdStyle alteration cell background based on cancer association rank (Generated by Claude Opus 4.6 with some manual tweaks)
Usage
render_symbol_assoc_style(
data,
rank_col = "TISSUE_ASSOC_RANK",
color_palette = pcgrr::color_palette
)